@@ -16,6 +16,14 @@ logger = logging.getLogger('pyrocko.client.isc')
 km = 1000.
 
 
+class ISCError(Exception):
+    pass
+
+
+class ISCBlocked(ISCError):
+    pass
+
+
 class ISC(EarthquakeCatalog):
     '''
     Interfacing the catalog of the Internation Seismological Centre (ISC).
@@ -79,13 +87,26 @@ class ISC(EarthquakeCatalog):
         logger.debug('Received page (%i bytes)' % len(page))
 
         if 'The search could not be run due to problems' in page:
-            logger.warn('%s\nurl: %s' % (page, url))
+            logger.warning('%s\nurl: %s' % (page, url))
             return
         elif 'No events were found.' in page:
             logger.info('No events were found.')
             events = []
         else:
-            data = quakeml.QuakeML.load_xml(string=page)
+            try:
+                data = quakeml.QuakeML.load_xml(string=page)
+            except Exception:
+                if page[:500].find(
+                        'Please try again in a few minutes') != -1:
+
+                    raise ISCBlocked(
+                        'Apparently, we have queried ISC too eagerly:\n'
+                        + '-' * 79 + '\n' + page + '\n' + '-' * 79)
+                else:
+                    raise ISCError(
+                        'Couldn\'t parse XML results from ISC:\n'
+                        + '-' * 79 + '\n' + page + '\n' + '-' * 79)
+
             events = data.get_pyrocko_events()
 
         for ev in events:
