@@ -2,7 +2,8 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
-'''Compressed datafiles for the CRUST2.0 model by Laske, Masters and Reif.
+'''
+Compressed datafiles for the CRUST2.0 model by Laske, Masters and Reif.
 
 Reference
 ---------
