@@ -21,6 +21,7 @@ from matplotlib import pyplot as plt
 from matplotlib import cm, transforms
 
 from pyrocko import gf, trace, cake, util, plot
+from pyrocko.response import DifferentiationResponse
 from pyrocko.plot import beachball
 from pyrocko.guts import load, Object, String, List, Float, Int, Bool, Dict
 from pyrocko.gf import Source, Target
@@ -456,7 +457,7 @@ class GreensFunctionTest(Object):
             if 'displacement_traces' not in tdict:
                 continue
             trcs = [trc.transfer(
-                transfer_function=trace.DifferentiationResponse())
+                transfer_function=DifferentiationResponse())
                 for trc in tdict['displacement_traces']]
             tdict['velocity_traces'] = trcs
             src_id, sen_id = tid.split('|')
@@ -1210,10 +1211,21 @@ class GreensFunctionTest(Object):
     @staticmethod
     def __drawGrid(ax, major=True, minor=True):
         if major:
-            ax.grid(b=True, which='major', c='grey', linestyle='-', alpha=.45)
+            ax.grid(
+                visible=True,
+                which='major',
+                c='grey',
+                linestyle='-',
+                alpha=.45)
+
         if minor:
             ax.minorticks_on()
-            ax.grid(b=True, which='minor', c='grey', linestyle=':', alpha=.8)
+            ax.grid(
+                visible=True,
+                which='minor',
+                c='grey',
+                linestyle=':',
+                alpha=.8)
 
     @staticmethod
     def __getFigureTitle(fig):
