@@ -772,9 +772,13 @@ class DiscretizedSource(Object):
     lons = Array.T(shape=(None,), dtype=float, optional=True)
     lat = Float.T(optional=True)
     lon = Float.T(optional=True)
-    north_shifts = Array.T(shape=(None,), dtype=float, optional=True)
-    east_shifts = Array.T(shape=(None,), dtype=float, optional=True)
-    depths = Array.T(shape=(None,), dtype=float)
+    north_shifts = Array.T(shape=(None,), dtype=num.float64, optional=True)
+    east_shifts = Array.T(shape=(None,), dtype=num.float64, optional=True)
+    depths = Array.T(shape=(None,), dtype=num.float64)
+    dl = Float.T(optional=True)
+    dw = Float.T(optional=True)
+    nl = Float.T(optional=True)
+    nw = Float.T(optional=True)
 
     @classmethod
     def check_scheme(cls, scheme):
@@ -1314,17 +1318,30 @@ class DiscretizedMTSource(DiscretizedSource):
         return sources
 
     def moments(self):
-        n = self.nelements
-        moments = num.zeros(n)
-        for i in range(n):
-            m = moment_tensor.symmat6(*self.m6s[i])
-            m_evals = num.linalg.eigh(m)[0]
+        moments = num.array(
+            [num.linalg.eigvalsh(moment_tensor.symmat6(*m6))
+             for m6 in self.m6s])
+        return num.linalg.norm(moments, axis=1) / num.sqrt(2.)
 
-            # incorrect for non-dc sources: !!!!
-            m0 = num.linalg.norm(m_evals)/math.sqrt(2.)
-            moments[i] = m0
+    def get_moment_rate(self, deltat=None):
+        moments = self.moments()
+        times = self.times
+        times -= times.min()
 
-        return moments
+        t_max = times.max()
+        mom_times = num.arange(0, t_max + 2 * deltat, deltat) - deltat
+        mom_times[mom_times > t_max] = t_max
+
+        # Right open histrogram bins
+        mom, _ = num.histogram(
+            times,
+            bins=mom_times,
+            weights=moments)
+
+        deltat = num.diff(mom_times)
+        mom_rate = mom / deltat
+
+        return mom_rate, mom_times[1:]
 
     def centroid(self):
         from pyrocko.gf.seismosizer import MTSource
@@ -2205,8 +2222,8 @@ class ConfigTypeB(Config):
     * Symmetries like in :py:class:`ConfigTypeA` but has additional index for
       receiver depth
 
-    * High level index variables: ``(source_depth, receiver_distance,
-      receiver_depth, component)``
+    * High level index variables: ``(receiver_depth, source_depth,
+      receiver_distance, component)``
     '''
 
     receiver_depth_min = Float.T(
@@ -2971,11 +2988,11 @@ def parse_grid_spec(spec):
 def start_stop_num(start, stop, step, num, mi, ma, inc, eps=1e-5):
     swap = step is not None and step < 0.
     if start is None:
-        start = [mi, ma][swap]
+        start = ma if swap else mi
     if stop is None:
-        stop = [ma, mi][swap]
+        stop = mi if swap else ma
     if step is None:
-        step = [inc, -inc][ma < mi]
+        step = -inc if ma < mi else inc
     if num is None:
         if (step < 0) != (stop-start < 0):
             raise GridSpecError()
