@@ -239,11 +239,14 @@ class StaticTarget(meta.MultiLocation):
 
     @property
     def ntargets(self):
-        ''' Number of targets held by instance. '''
+        '''
+        Number of targets held by instance.
+        '''
         return self.ncoords
 
     def get_targets(self):
-        ''' Discretizes the multilocation target into a list of
+        '''
+        Discretizes the multilocation target into a list of
         :class:`Target:`
 
         :returns: :class:`Target`
@@ -283,7 +286,7 @@ class SatelliteTarget(StaticTarget):
     '''
     theta = Array.T(
         shape=(None,),
-        dtype=num.float,
+        dtype=float,
         serialize_as='base64-compat',
         help='Horizontal angle towards satellite\'s line of sight in radians.'
              '\n\n        .. important::\n\n'
@@ -292,7 +295,7 @@ class SatelliteTarget(StaticTarget):
 
     phi = Array.T(
         shape=(None,),
-        dtype=num.float,
+        dtype=float,
         serialize_as='base64-compat',
         help='Theta is look vector elevation angle towards satellite from'
              ' horizon in radians. Matrix of theta towards satellite\'s'
