@@ -17,7 +17,7 @@ import logging
 import traceback
 import tempfile
 
-from .qt_compat import qc, qw, getSaveFileName, use_pyqt5
+from .qt_compat import qc, qw, getSaveFileName
 
 from pyrocko import pile, config
 from pyrocko.util import quote
@@ -27,22 +27,13 @@ from .util import (ValControl, LinValControl, FigureFrame, WebKitFrame,
                    load_markers, save_markers)
 
 
-if sys.version_info >= (3, 0):
-    from importlib import reload
-
+from importlib import reload
 
 Marker, load_markers, save_markers  # noqa
 
 logger = logging.getLogger('pyrocko.gui.snuffling')
 
 
-def fnpatch(x):
-    if use_pyqt5:
-        return x
-    else:
-        return x, None
-
-
 class MyFrame(qw.QFrame):
     widgetVisibilityChanged = qc.pyqtSignal(bool)
 
@@ -76,7 +67,9 @@ class Param(object):
             self, name, ident, default, minimum, maximum,
             low_is_none=None,
             high_is_none=None,
-            low_is_zero=False):
+            low_is_zero=False,
+            tracking=True,
+            type=float):
 
         if low_is_none and default == minimum:
             default = None
@@ -91,6 +84,9 @@ class Param(object):
         self.low_is_none = low_is_none
         self.high_is_none = high_is_none
         self.low_is_zero = low_is_zero
+        self.tracking = tracking
+        self.type = type
+
         self._control = None
 
 
@@ -295,7 +291,7 @@ class Snuffling(object):
                     '--' + param.ident,
                     dest=param.ident,
                     default=param.default,
-                    type='float',
+                    type={float: 'float', int: 'int'}[param.type],
                     help=param.name)
 
     def setup_cli(self):
@@ -1210,12 +1206,14 @@ class Snuffling(object):
                     if param.minimum <= 0.0:
                         param_control = LinValControl(
                             high_is_none=param.high_is_none,
-                            low_is_none=param.low_is_none)
+                            low_is_none=param.low_is_none,
+                            type=param.type)
                     else:
                         param_control = ValControl(
                             high_is_none=param.high_is_none,
                             low_is_none=param.low_is_none,
-                            low_is_zero=param.low_is_zero)
+                            low_is_zero=param.low_is_zero,
+                            type=param.type)
 
                     param_control.setup(
                         param.name,
@@ -1224,6 +1222,7 @@ class Snuffling(object):
                         param.default,
                         iparam)
 
+                    param_control.set_tracking(param.tracking)
                     param_control.valchange.connect(
                         self.modified_snuffling_panel)
 
@@ -1267,7 +1266,7 @@ class Snuffling(object):
                             self.switch_on_snuffling_panel)
 
                         self._param_controls[param.ident] = param_widget
-                        swlayout.addWidget(param_widget, isw/10, isw % 10)
+                        swlayout.addWidget(param_widget, isw//10, isw % 10)
                         isw += 1
 
                 swframe = qw.QFrame(sarea)
@@ -1430,11 +1429,11 @@ class Snuffling(object):
         if not dir and self._previous_input_filename:
             dir = self._previous_input_filename
 
-        fn, _ = fnpatch(qw.QFileDialog.getOpenFileName(
+        fn, _ = qw.QFileDialog.getOpenFileName(
             self.get_viewer(),
             caption,
             dir,
-            filter))  # selected_filter)
+            filter)
 
         if not fn:
             raise UserCancelled()
