@@ -3,10 +3,13 @@
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
 from __future__ import absolute_import
-from . import (minmax, rms, stalta, geofon, ampspec,
-               catalogs, download, cake_phase, seismosizer, map)
-modules = [minmax, rms, download, stalta, geofon, ampspec, catalogs,
-           map, cake_phase, seismosizer]
+from . import (
+    minmax, rms, stalta, geofon, ampspec, catalogs, download, cake_phase,
+    seismosizer, map, polarization)
+
+modules = [
+    minmax, rms, download, stalta, geofon, ampspec, catalogs, map, cake_phase,
+    seismosizer, polarization]
 
 
 def __snufflings__():
