@@ -6,12 +6,16 @@
 from __future__ import absolute_import
 
 import time
+import logging
 from collections import defaultdict
 
 import numpy as num
 
 from pyrocko.gui.snuffling import Snuffling, Param, Switch
 from pyrocko.trace import Trace, NoData
+from pyrocko import util
+
+logger = logging.getLogger('pyrocko.gui.snuffling.rms')
 
 
 class RootMeanSquareSnuffling(Snuffling):
@@ -25,7 +29,7 @@ class RootMeanSquareSnuffling(Snuffling):
         Customization of the snuffling.
         '''
 
-        self.set_name('Block RMS')
+        self.set_name('RMS')
 
         self.add_parameter(Param(
             'Highpass [Hz]', 'highpass', None, 0.001, 1000.,
@@ -41,6 +45,9 @@ class RootMeanSquareSnuffling(Snuffling):
         self.add_parameter(Switch(
             'Group channels', 'group_channels', True))
 
+        self.add_parameter(Switch(
+            'Log RMS', 'log', False))
+
         self.add_trigger(
             'Copy passband from Main', self.copy_passband)
 
@@ -102,9 +109,19 @@ class RootMeanSquareSnuffling(Snuffling):
 
                 try:
                     tr.chop(batch.tmin, batch.tmax)
+                    val = 0.0
+                    if tr.ydata.size != 0:
+                        y = tr.ydata.astype(float)
+                        if num.any(num.isnan(y)):
+                            logger.error(
+                                'NaN value in trace %s (%s - %s)' % (
+                                    '.'.join(tr.nslc_id),
+                                    util.time_to_str(tr.tmin),
+                                    util.time_to_str(tr.tmax)))
 
-                    rms[grouping(tr.nslc_id)].append(
-                        num.sqrt(num.sum(tr.ydata**2)/tr.ydata.size))
+                        val = num.sqrt(num.sum(y**2)/tr.ydata.size)
+
+                    rms[grouping(tr.nslc_id)].append(val)
 
                 except NoData:
                     continue
@@ -116,6 +133,7 @@ class RootMeanSquareSnuffling(Snuffling):
                 insert_now = True
                 tlast = tnow
 
+            to_add = []
             for key, values in rms.items():
                 target = targets.get(key, None)
 
@@ -124,7 +142,7 @@ class RootMeanSquareSnuffling(Snuffling):
                         or insert_now:
 
                     if target:
-                        self.add_trace(target)
+                        to_add.append(target)
 
                     target = targets[key] = Trace(
                         network=key[0],
@@ -137,10 +155,16 @@ class RootMeanSquareSnuffling(Snuffling):
                         meta={'tabu': True})
 
                 value = num.atleast_1d(
-                    num.sqrt(num.sum(num.array(values, dtype=num.float)**2)))
+                    num.sqrt(num.sum(num.array(values, dtype=float)**2)))
+
+                if self.log and value != 0.0:
+                    value = num.log(value)
 
                 targets[key].append(value)
 
+            if to_add:
+                self.add_traces(to_add)
+
         # add the newly created traces to the viewer
         if targets.values():
             self.add_traces(list(targets.values()))
