@@ -4,13 +4,16 @@
 # ---|P------/S----------~Lg----------
 from __future__ import absolute_import, print_function
 
-import sys
 import math
 import time
 import numpy as num
 import logging
+import enum
 
-from .qt_compat import qc, qg, qw, use_pyqt5
+from matplotlib.cm import get_cmap
+from matplotlib.colors import Normalize
+
+from .qt_compat import qc, qg, qw
 
 from .marker import Marker, PhaseMarker, EventMarker  # noqa
 from .marker import MarkerParseError, MarkerOneNSLCRequired  # noqa
@@ -18,8 +21,10 @@ from .marker import load_markers, save_markers  # noqa
 from pyrocko import plot
 
 
-if sys.version_info > (3,):
-    buffer = memoryview
+try:
+    from PyQt5.QtWebEngineWidgets import QWebEngineView as WebView
+except ImportError:
+    from PyQt5.QtWebKitWidgets import QWebView as WebView
 
 
 logger = logging.getLogger('pyrocko.gui.util')
@@ -33,13 +38,26 @@ def make_QPolygonF(xdata, ydata):
     aa = num.ndarray(
         shape=(len(ydata), 2),
         dtype=num.float64,
-        buffer=buffer(vptr))
+        buffer=memoryview(vptr))
     aa.setflags(write=True)
     aa[:, 0] = xdata
     aa[:, 1] = ydata
     return qpoints
 
 
+def get_colormap_qimage(cmap_name, vmin=None, vmax=None):
+    NCOLORS = 512
+    norm = Normalize()
+    norm.vmin = vmin
+    norm.vmax = vmax
+
+    return qg.QImage(
+        get_cmap(cmap_name)(
+            norm(num.linspace(0., 1., NCOLORS)),
+            alpha=None, bytes=True),
+        NCOLORS, 1, qg.QImage.Format_RGBX8888)
+
+
 class Label(object):
     def __init__(
             self, p, x, y, label_str,
@@ -55,7 +73,7 @@ class Label(object):
         text.setDefaultStyleSheet('span { color: %s; }' % color.name())
         text.setHtml('<span>%s</span>' % label_str)
         s = text.size()
-        rect = qc.QRectF(0., 0., s.width(), s.height())
+        rect = qc.QRect(0, 0, int(s.width()), int(s.height()))
         tx, ty = x, y
 
         if 'B' in anchor:
@@ -63,11 +81,11 @@ class Label(object):
         if 'R' in anchor:
             tx -= rect.width()
         if 'M' in anchor:
-            ty -= rect.height()/2.
+            ty -= rect.height() // 2
         if 'C' in anchor:
-            tx -= rect.width()/2.
+            tx -= rect.width() // 2
 
-        rect.translate(tx, ty)
+        rect.translate(int(tx), int(ty))
         self.rect = rect
         self.text = text
         self.outline = outline
@@ -85,7 +103,7 @@ class Label(object):
             oldpen = p.pen()
             oldbrush = p.brush()
             p.setBrush(self.label_bg)
-            rect.adjust(-2., 0., 2., 0.)
+            rect.adjust(-2, 0, 2, 0)
             p.drawRect(rect)
             p.setPen(oldpen)
             p.setBrush(oldbrush)
@@ -94,9 +112,9 @@ class Label(object):
             if self.label_bg:
                 p.fillRect(rect, self.label_bg)
 
-        p.translate(tx, ty)
+        p.translate(int(tx), int(ty))
         self.text.drawContents(p)
-        p.translate(-tx, -ty)
+        p.translate(-int(tx), -int(ty))
 
 
 def draw_label(p, x, y, label_str, label_bg, anchor='BL', outline=False):
@@ -111,23 +129,24 @@ def draw_label(p, x, y, label_str, label_bg, anchor='BL', outline=False):
     if 'R' in anchor:
         tx -= rect.width()
     if 'M' in anchor:
-        ty += rect.height()/2.
+        ty += rect.height() // 2
     if 'C' in anchor:
-        tx -= rect.width()/2.
+        tx -= rect.width() // 2
 
-    rect.translate(tx, ty)
+    rect.translate(int(tx), int(ty))
     if outline:
         oldpen = p.pen()
         oldbrush = p.brush()
         p.setBrush(label_bg)
-        rect.adjust(-2., 0., 2., 0.)
+        rect.adjust(-2, 0, 2, 0)
         p.drawRect(rect)
         p.setPen(oldpen)
         p.setBrush(oldbrush)
 
     else:
         p.fillRect(rect, label_bg)
-    p.drawText(tx, ty, label)
+
+    p.drawText(int(tx), int(ty), label)
 
 
 def get_err_palette():
@@ -136,7 +155,7 @@ def get_err_palette():
     return err_palette
 
 
-class MySlider(qw.QSlider):
+class QSliderNoWheel(qw.QSlider):
 
     def wheelEvent(self, ev):
         ev.ignore()
@@ -220,10 +239,15 @@ class MyValueEdit(qw.QLineEdit):
             else:
                 t = 'off'
 
+        if t in ('off', 'below', 'above'):
+            self.setStyleSheet("font-style: italic;")
+        else:
+            self.setStyleSheet(None)
+
         self.setText(t)
 
 
-class ValControl(qc.QObject):
+class ValControl(qw.QWidget):
 
     valchange = qc.pyqtSignal(object, int)
 
@@ -232,6 +256,7 @@ class ValControl(qc.QObject):
             low_is_none=False,
             high_is_none=False,
             low_is_zero=False,
+            type=float,
             *args):
 
         qc.QObject.__init__(self, *args)
@@ -244,7 +269,7 @@ class ValControl(qc.QObject):
             high_is_none=high_is_none,
             low_is_zero=low_is_zero)
         self.lvalue.setFixedWidth(100)
-        self.slider = MySlider(qc.Qt.Horizontal)
+        self.slider = QSliderNoWheel(qc.Qt.Horizontal)
         self.slider.setSizePolicy(
             qw.QSizePolicy(qw.QSizePolicy.Expanding, qw.QSizePolicy.Minimum))
         self.slider.setMaximum(10000)
@@ -262,6 +287,7 @@ class ValControl(qc.QObject):
         self.lvalue.edited.connect(
                      self.edited)
 
+        self.type = type
         self.mute = False
 
     def widgets(self):
@@ -272,9 +298,13 @@ class ValControl(qc.QObject):
             return 0
 
         a = math.log(self.ma/self.mi) / 10000.
-        return self.mi*math.exp(a*svalue)
+        value = self.mi*math.exp(a*svalue)
+        value = self.type(value)
+        return value
 
     def v2s(self, value):
+        value = self.type(value)
+
         if value == 0 or self.mi == 0:
             return 0
 
@@ -336,18 +366,23 @@ class ValControl(qc.QObject):
         self.lvalue.blockSignals(False)
         self.mute = False
 
+    def set_tracking(self, tracking):
+        self.slider.setTracking(tracking)
+
     def get_value(self):
         return self.cur
 
     def slided(self, val):
         if self.cursl != val:
             self.cursl = val
-            self.cur = self.s2v(self.cursl)
+            cur = self.s2v(self.cursl)
 
-            self.lvalue.blockSignals(True)
-            self.lvalue.setValue(self.cur)
-            self.lvalue.blockSignals(False)
-            self.fire_valchange()
+            if cur != self.cur:
+                self.cur = cur
+                self.lvalue.blockSignals(True)
+                self.lvalue.setValue(self.cur)
+                self.lvalue.blockSignals(False)
+                self.fire_valchange()
 
     def edited(self, val):
         if self.cur != val:
@@ -362,6 +397,7 @@ class ValControl(qc.QObject):
             self.fire_valchange()
 
     def fire_valchange(self):
+
         if self.mute:
             return
 
@@ -383,14 +419,355 @@ class ValControl(qc.QObject):
 class LinValControl(ValControl):
 
     def s2v(self, svalue):
-        return svalue/10000. * (self.ma-self.mi) + self.mi
+        value = svalue/10000. * (self.ma-self.mi) + self.mi
+        value = self.type(value)
+        return value
 
     def v2s(self, value):
+        value = self.type(value)
         if self.ma == self.mi:
             return 0
         return int(round((value-self.mi)/(self.ma-self.mi) * 10000.))
 
 
+class ColorbarControl(qw.QWidget):
+
+    AVAILABLE_CMAPS = (
+        'viridis',
+        'plasma',
+        'magma',
+        'binary',
+        'Reds',
+        'copper',
+        'seismic',
+        'RdBu',
+        'YlGn',
+    )
+
+    DEFAULT_CMAP = 'viridis'
+
+    cmap_changed = qc.pyqtSignal(str)
+    show_absolute_toggled = qc.pyqtSignal(bool)
+    show_integrate_toggled = qc.pyqtSignal(bool)
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        self.lname = qw.QLabel("Colormap")
+        self.lname.setSizePolicy(
+            qw.QSizePolicy(qw.QSizePolicy.Minimum, qw.QSizePolicy.Minimum))
+
+        self.cmap_options = qw.QComboBox()
+        self.cmap_options.setIconSize(qc.QSize(64, 12))
+        for ic, cmap in enumerate(self.AVAILABLE_CMAPS):
+            pixmap = qg.QPixmap.fromImage(
+                get_colormap_qimage(cmap))
+            icon = qg.QIcon(pixmap.scaled(64, 12))
+
+            self.cmap_options.addItem(icon, '', cmap)
+            self.cmap_options.setItemData(ic, cmap, qc.Qt.ToolTipRole)
+
+        # self.cmap_options.setCurrentIndex(self.cmap_name)
+        self.cmap_options.currentIndexChanged.connect(self.set_cmap)
+        self.cmap_options.setSizePolicy(
+            qw.QSizePolicy(qw.QSizePolicy.Minimum, qw.QSizePolicy.Minimum))
+
+        self.colorslider = ColorbarSlider(self)
+        self.colorslider.setSizePolicy(
+            qw.QSizePolicy.MinimumExpanding | qw.QSizePolicy.ExpandFlag,
+            qw.QSizePolicy.MinimumExpanding | qw.QSizePolicy.ExpandFlag
+        )
+        self.clip_changed = self.colorslider.clip_changed
+
+        btn_size = qw.QSizePolicy(
+            qw.QSizePolicy.Maximum | qw.QSizePolicy.ShrinkFlag,
+            qw.QSizePolicy.Maximum | qw.QSizePolicy.ShrinkFlag)
+
+        self.symetry_toggle = qw.QPushButton()
+        self.symetry_toggle.setIcon(
+            qg.QIcon.fromTheme('object-flip-horizontal'))
+        self.symetry_toggle.setToolTip('Symetric clip values')
+        self.symetry_toggle.setSizePolicy(btn_size)
+        self.symetry_toggle.setCheckable(True)
+        self.symetry_toggle.toggled.connect(self.toggle_symetry)
+        self.symetry_toggle.setChecked(True)
+
+        self.reverse_toggle = qw.QPushButton()
+        self.reverse_toggle.setIcon(
+            qg.QIcon.fromTheme('object-rotate-right'))
+        self.reverse_toggle.setToolTip('Reverse the colormap')
+        self.reverse_toggle.setSizePolicy(btn_size)
+        self.reverse_toggle.setCheckable(True)
+        self.reverse_toggle.toggled.connect(self.toggle_reverse_cmap)
+
+        self.abs_toggle = qw.QPushButton()
+        self.abs_toggle.setIcon(
+            qg.QIcon.fromTheme('go-bottom'))
+        self.abs_toggle.setToolTip('Show absolute values')
+        self.abs_toggle.setSizePolicy(btn_size)
+        self.abs_toggle.setCheckable(True)
+        self.abs_toggle.toggled.connect(self.toggle_absolute)
+
+        self.int_toggle = qw.QPushButton()
+        self.int_toggle.setText('∫')
+        self.int_toggle.setToolTip(
+            u'Integrate traces (e.g. strain rate → strain)')
+        self.int_toggle.setSizePolicy(btn_size)
+        self.int_toggle.setCheckable(True)
+        self.int_toggle.setMaximumSize(
+            24,
+            self.int_toggle.maximumSize().height())
+        self.int_toggle.toggled.connect(self.show_integrate_toggled.emit)
+
+        v_splitter = qw.QFrame()
+        v_splitter.setFrameShape(qw.QFrame.VLine)
+        v_splitter.setFrameShadow(qw.QFrame.Sunken)
+
+        self.controls = qw.QWidget()
+        layout = qw.QHBoxLayout()
+        layout.addWidget(self.colorslider)
+        layout.addWidget(self.symetry_toggle)
+        layout.addWidget(self.reverse_toggle)
+        layout.addWidget(v_splitter)
+        layout.addWidget(self.abs_toggle)
+        layout.addWidget(self.int_toggle)
+        self.controls.setLayout(layout)
+
+        self.set_cmap_name(self.DEFAULT_CMAP)
+
+    def set_cmap(self, idx):
+        self.set_cmap_name(self.cmap_options.itemData(idx))
+
+    def set_cmap_name(self, cmap_name):
+        self.cmap_name = cmap_name
+        self.colorslider.set_cmap_name(cmap_name)
+        self.cmap_changed.emit(cmap_name)
+
+    def get_cmap(self):
+        return self.cmap_name
+
+    def toggle_symetry(self, toggled):
+        self.colorslider.set_symetry(toggled)
+
+    def toggle_reverse_cmap(self):
+        cmap = self.get_cmap()
+        if cmap.endswith('_r'):
+            r_cmap = cmap.rstrip('_r')
+        else:
+            r_cmap = cmap + '_r'
+        self.set_cmap_name(r_cmap)
+
+    def toggle_absolute(self, toggled):
+        self.symetry_toggle.setChecked(not toggled)
+        self.show_absolute_toggled.emit(toggled)
+
+    def widgets(self):
+        return (self.lname, self.cmap_options, self.controls)
+
+
+class ColorbarSlider(qw.QWidget):
+    DEFAULT_CMAP = 'viridis'
+    CORNER_THRESHOLD = 10
+    MIN_WIDTH = .05
+
+    clip_changed = qc.pyqtSignal(float, float)
+
+    class COMPONENTS(enum.Enum):
+        LeftLine = 1
+        RightLine = 2
+        Center = 3
+
+    def __init__(self, *args, cmap_name=None):
+        super().__init__()
+        self.cmap_name = cmap_name or self.DEFAULT_CMAP
+        self.clip_min = 0.
+        self.clip_max = 1.
+
+        self._sym_locked = True
+        self._mouse_inside = False
+        self._window = None
+        self._old_pos = None
+        self._component_grabbed = None
+
+        self.setMouseTracking(True)
+
+    def set_cmap_name(self, cmap_name):
+        self.cmap_name = cmap_name
+        self.repaint()
+
+    def get_cmap_name(self):
+        return self.cmap_name
+
+    def set_symetry(self, symetry):
+        self._sym_locked = symetry
+        if self._sym_locked:
+            clip_max = 1. - min(self.clip_min, 1.-self.clip_max)
+            clip_min = 1. - clip_max
+            self.set_clip(clip_min, clip_max)
+
+    def _set_window(self, window):
+        self._window = window
+
+    def _get_left_line(self):
+        rect = self._get_active_rect()
+        if not rect:
+            return
+        return qc.QLineF(rect.left(), 0, rect.left(), rect.height())
+
+    def _get_right_line(self):
+        rect = self._get_active_rect()
+        if not rect:
+            return
+        return qc.QLineF(rect.right(), 0, rect.right(), rect.height())
+
+    def _get_active_rect(self):
+        if not self._window:
+            return
+        rect = qc.QRect(self._window)
+        width = rect.width()
+        rect.setLeft(width * self.clip_min)
+        rect.setRight(width * self.clip_max)
+        return rect
+
+    def set_clip(self, clip_min, clip_max):
+        if clip_min < 0. or clip_max > 1.:
+            return
+        if clip_max - clip_min < self.MIN_WIDTH:
+            return
+
+        self.clip_min = clip_min
+        self.clip_max = clip_max
+        self.repaint()
+        self.clip_changed.emit(self.clip_min, self.clip_max)
+
+    def mousePressEvent(self, event):
+        act_rect = self._get_active_rect()
+        if event.buttons() != qc.Qt.MouseButton.LeftButton:
+            self._component_grabbed = None
+            return
+
+        dist_left = abs(event.pos().x() - act_rect.left())
+        dist_right = abs(event.pos().x() - act_rect.right())
+
+        if 0 < dist_left < self.CORNER_THRESHOLD:
+            self._component_grabbed = self.COMPONENTS.LeftLine
+            self.setCursor(qg.QCursor(qc.Qt.CursorShape.SizeHorCursor))
+        elif 0 < dist_right < self.CORNER_THRESHOLD:
+            self._component_grabbed = self.COMPONENTS.RightLine
+            self.setCursor(qg.QCursor(qc.Qt.CursorShape.SizeHorCursor))
+        else:
+            self.setCursor(qg.QCursor())
+
+    def mouseReleaseEvent(self, event):
+        self._component_grabbed = None
+        self.repaint()
+
+    def mouseDoubleClickEvent(self, event):
+        self.set_clip(0., 1.)
+
+    def wheelEvent(self, event):
+        event.accept()
+        if not self._sym_locked:
+            return
+
+        delta = event.angleDelta().y()
+        delta = -delta / 5e3
+        clip_min_new = max(self.clip_min + delta, 0.)
+        clip_max_new = min(self.clip_max - delta, 1.)
+        self._mouse_inside = True
+        self.set_clip(clip_min_new, clip_max_new)
+
+    def mouseMoveEvent(self, event):
+        act_rect = self._get_active_rect()
+
+        if not self._component_grabbed:
+            dist_left = abs(event.pos().x() - act_rect.left())
+            dist_right = abs(event.pos().x() - act_rect.right())
+
+            if 0 <= dist_left < self.CORNER_THRESHOLD or \
+                    0 <= dist_right < self.CORNER_THRESHOLD:
+                self.setCursor(qg.QCursor(qc.Qt.CursorShape.SizeHorCursor))
+            else:
+                self.setCursor(qg.QCursor())
+
+        if self._old_pos and self._component_grabbed:
+            shift = (event.pos() - self._old_pos).x() / self._window.width()
+
+            if self._component_grabbed is self.COMPONENTS.LeftLine:
+                clip_min_new = max(self.clip_min + shift, 0.)
+                clip_max_new = \
+                    min(self.clip_max - shift, 1.) \
+                    if self._sym_locked else self.clip_max
+
+            elif self._component_grabbed is self.COMPONENTS.RightLine:
+                clip_max_new = min(self.clip_max + shift, 1.)
+                clip_min_new = \
+                    max(self.clip_min - shift, 0.) \
+                    if self._sym_locked else self.clip_min
+
+            self.set_clip(clip_min_new, clip_max_new)
+
+        self._old_pos = event.pos()
+
+    def enterEvent(self, e):
+        self._mouse_inside = True
+        self.repaint()
+
+    def leaveEvent(self, e):
+        self._mouse_inside = False
+        self.repaint()
+
+    def paintEvent(self, e):
+        p = qg.QPainter(self)
+        self._set_window(p.window())
+
+        p.drawImage(
+            p.window(),
+            get_colormap_qimage(self.cmap_name, self.clip_min, self.clip_max))
+
+        left_line = self._get_left_line()
+        right_line = self._get_right_line()
+
+        pen = qg.QPen()
+        pen.setWidth(2)
+        pen.setStyle(qc.Qt.DotLine)
+        pen.setBrush(qc.Qt.white)
+        p.setPen(pen)
+        p.setCompositionMode(
+            qg.QPainter.CompositionMode.CompositionMode_Difference)
+
+        p.drawLine(left_line)
+        p.drawLine(right_line)
+
+        label_rect = self._get_active_rect()
+        label_rect.setLeft(label_rect.left() + 5)
+        label_rect.setRight(label_rect.right() - 5)
+        label_left_rect = qc.QRectF(label_rect)
+        label_right_rect = qc.QRectF(label_rect)
+        label_left_align = qc.Qt.AlignLeft
+        label_right_align = qc.Qt.AlignRight
+
+        if label_rect.left() > 50:
+            label_left_rect.setRight(label_rect.left() - 10)
+            label_left_rect.setLeft(0)
+            label_left_align = qc.Qt.AlignRight
+
+        if self._window.right() - label_rect.right() > 50:
+            label_right_rect.setLeft(label_rect.right() + 10)
+            label_right_rect.setRight(self._window.right())
+            label_right_align = qc.Qt.AlignLeft
+
+        if self._mouse_inside or self._component_grabbed:
+            p.drawText(
+                label_left_rect,
+                label_left_align | qc.Qt.AlignVCenter,
+                '%d%%' % round(self.clip_min * 100))
+            p.drawText(
+                label_right_rect,
+                label_right_align | qc.Qt.AlignVCenter,
+                '%d%%' % round(self.clip_max * 100))
+
+
 class Progressbar(object):
     def __init__(self, parent, name, can_abort=True):
         self.parent = parent
@@ -518,13 +895,7 @@ class FigureFrame(qw.QFrame):
 
         import matplotlib
         matplotlib.rcdefaults()
-        if use_pyqt5:
-            try:
-                matplotlib.rcParams['backend'] = 'Qt5Agg'
-            except ValueError:
-                matplotlib.rcParams['backend'] = 'Qt4Agg'
-        else:
-            matplotlib.rcParams['backend'] = 'Qt4Agg'
+        matplotlib.rcParams['backend'] = 'Qt5Agg'
 
         matplotlib.rc('xtick', direction='out', labelsize=fontsize)
         matplotlib.rc('ytick', direction='out', labelsize=fontsize)
@@ -584,22 +955,11 @@ class FigureFrame(qw.QFrame):
 
         from matplotlib.figure import Figure
 
-        if use_pyqt5:
-            from matplotlib.backends.backend_qt5agg import \
-                NavigationToolbar2QT as NavigationToolbar
+        from matplotlib.backends.backend_qt5agg import \
+            NavigationToolbar2QT as NavigationToolbar
 
-            from matplotlib.backends.backend_qt5agg \
-                import FigureCanvasQTAgg as FigureCanvas
-        else:
-            try:
-                from matplotlib.backends.backend_qt4agg import \
-                    NavigationToolbar2QTAgg as NavigationToolbar
-            except ImportError:
-                from matplotlib.backends.backend_qt4agg import \
-                    NavigationToolbar2QT as NavigationToolbar
-
-            from matplotlib.backends.backend_qt4agg \
-                import FigureCanvasQTAgg as FigureCanvas
+        from matplotlib.backends.backend_qt5agg \
+            import FigureCanvasQTAgg as FigureCanvas
 
         layout = qw.QGridLayout()
         layout.setContentsMargins(0, 0, 0, 0)
@@ -635,15 +995,6 @@ class FigureFrame(qw.QFrame):
 class WebKitFrame(qw.QFrame):
 
     def __init__(self, url=None, parent=None):
-        if use_pyqt5:
-            try:
-                from PyQt5.QtWebEngineWidgets import QWebEngineView as WebView
-            except (ImportError):
-                from PyQt5.QtWebKitWidgets import QWebView as WebView
-
-        else:
-            from PyQt4.QtWebKit import QWebView as WebView
-
         qw.QFrame.__init__(self, parent)
         layout = qw.QGridLayout()
         layout.setContentsMargins(0, 0, 0, 0)
@@ -659,7 +1010,7 @@ class VTKFrame(qw.QFrame):
 
     def __init__(self, actors=None, parent=None):
         import vtk
-        from vtk.qt4.QVTKRenderWindowInteractor import \
+        from vtk.qt.QVTKRenderWindowInteractor import \
             QVTKRenderWindowInteractor
 
         qw.QFrame.__init__(self, parent)
