@@ -77,8 +77,8 @@ g_guessable_xmlns = {}
 guts_types = [
     'Object', 'SObject', 'String', 'Unicode', 'Int', 'Float',
     'Complex', 'Bool', 'Timestamp', 'DateTimestamp', 'StringPattern',
-    'UnicodePattern', 'StringChoice', 'List', 'Dict', 'Tuple', 'Union',
-    'Choice', 'Any']
+    'UnicodePattern', 'StringChoice', 'IntChoice', 'List', 'Dict', 'Tuple',
+    'Union', 'Choice', 'Any']
 
 us_to_cc_regex = re.compile(r'([a-z])_([a-z])')
 
@@ -605,23 +605,24 @@ class TBase(object):
         return []
 
     def classname_for_help(self, strip_module=''):
+
+        if self.dummy_cls is not self.cls:
+            if self.dummy_cls.__module__ == strip_module:
+                sadd = ' (:py:class:`%s`)' % (
+                    self.dummy_cls.__name__)
+            else:
+                sadd = ' (:py:class:`%s.%s`)' % (
+                    self.dummy_cls.__module__, self.dummy_cls.__name__)
+        else:
+            sadd = ''
+
         if self.dummy_cls in guts_plain_dummy_types:
             return '``%s``' % self.cls.__name__
 
         elif self.dummy_cls.dummy_for_description:
-            return self.dummy_cls.dummy_for_description
+            return '%s%s' % (self.dummy_cls.dummy_for_description, sadd)
 
         else:
-            if self.dummy_cls is not self.cls:
-                if self.dummy_cls.__module__ == strip_module:
-                    sadd = ' (:py:class:`%s`)' % (
-                        self.dummy_cls.__name__)
-                else:
-                    sadd = ' (:py:class:`%s.%s`)' % (
-                        self.dummy_cls.__module__, self.dummy_cls.__name__)
-            else:
-                sadd = ''
-
             def sclass(cls):
                 mod = cls.__module__
                 clsn = cls.__name__
@@ -638,7 +639,7 @@ class TBase(object):
                 return '(%s)%s' % (
                     ' | '.join(sclass(cls) for cls in self.cls), sadd)
             else:
-                return '%s%s' % (sclass(cls), sadd)
+                return '%s%s' % (sclass(self.cls), sadd)
 
     @classmethod
     def props_help_string(cls):
@@ -1279,6 +1280,30 @@ class Tuple(Object):
                         strip_module=strip_module))
 
 
+unit_factors = dict(
+    s=1.0,
+    m=60.0,
+    h=3600.0,
+    d=24*3600.0,
+    y=365*24*3600.0)
+
+
+class Duration(Object):
+    dummy_for = float
+
+    class __T(TBase):
+
+        def regularize_extra(self, val):
+            if isinstance(val, (str, newstr)):
+                unit = val[-1]
+                if unit in unit_factors:
+                    return float(val[:-1]) * unit_factors[unit]
+                else:
+                    return float(val)
+
+            return val
+
+
 re_tz = re.compile(r'(Z|([+-][0-2][0-9])(:?([0-5][0-9]))?)$')
 
 
@@ -1487,6 +1512,37 @@ class StringChoice(String):
             return doc % {'choices': repr(dcls.choices)}
 
 
+class IntChoice(Int):
+
+    '''
+    Any ``int`` out of ``%(choices)s``.
+    '''
+
+    dummy_for = int
+    choices = []
+
+    class __T(Int.T):
+        def __init__(self, choices=None, *args, **kwargs):
+            Int.T.__init__(self, *args, **kwargs)
+
+            if choices is not None:
+                self.choices = choices
+            else:
+                self.choices = self.dummy_cls.choices
+
+        def validate_extra(self, val):
+            if val not in self.choices:
+                raise ValidationError(
+                    '%s: %i is not a valid choice out of %s' % (
+                        self.xname(), val, repr(self.choices)))
+
+        @classmethod
+        def class_help_string(cls):
+            dcls = cls.dummy_cls
+            doc = dcls.__doc_template__ or IntChoice.__doc_template__
+            return doc % {'choices': repr(dcls.choices)}
+
+
 # this will not always work...
 class Union(Object):
     members = []
@@ -2027,7 +2083,9 @@ def clone(x, pool=None):
         x_copy = pool[id(x)]
 
     else:
-        if isinstance(x, Object):
+        if isinstance(x, SObject):
+            x_copy = x.__class__(str(x))
+        elif isinstance(x, Object):
             d = {}
             for (prop, y) in x.T.ipropvals(x):
                 if y is not None:
