@@ -79,13 +79,13 @@ class Array(Object):
 
                 elif self.serialize_as == 'base64':
                     data = b64decode(val)
-                    val = num.fromstring(
+                    val = num.frombuffer(
                         data, dtype=self.serialize_dtype).astype(self.dtype)
 
                 elif self.serialize_as == 'base64-compat':
                     try:
                         data = b64decode(val)
-                        val = num.fromstring(
+                        val = num.frombuffer(
                             data,
                             dtype=self.serialize_dtype).astype(self.dtype)
                     except binascii.Error:
@@ -136,7 +136,7 @@ class Array(Object):
                     dtype = self.dtype or \
                         restricted_dtype_map_rev[serialize_dtype]
 
-                    val = num.fromstring(
+                    val = num.frombuffer(
                         data, dtype=serialize_dtype).astype(dtype)
 
                     if val.size != num.product(shape):
@@ -152,25 +152,26 @@ class Array(Object):
         def validate_extra(self, val):
             if not isinstance(val, num.ndarray):
                 raise ValidationError(
-                    'object is not of type numpy.ndarray: %s' % type(val))
+                    'object %s is not of type numpy.ndarray: %s' % (
+                        self.xname(), type(val)))
             if self.dtype is not None and self.dtype != val.dtype:
                 raise ValidationError(
-                    'array not of required type: need %s, got %s' % (
-                        self.dtype, val.dtype))
+                    'array %s not of required type: need %s, got %s' % (
+                        self.xname(), self.dtype, val.dtype))
 
             if self.shape is not None:
                 la, lb = len(self.shape), len(val.shape)
                 if la != lb:
                     raise ValidationError(
-                        'array dimension mismatch: need %i, got %i' % (
-                            la, lb))
+                        'array %s dimension mismatch: need %i, got %i' % (
+                            self.xname(), la, lb))
 
                 for a, b in zip(self.shape, val.shape):
                     if a is not None:
                         if a != b:
                             raise ValidationError(
-                                'array shape mismatch: need %s, got: %s' % (
-                                    self.shape, val.shape))
+                                'array %s shape mismatch: need %s, got: %s' % (
+                                    self.xname(), self.shape, val.shape))
 
         def to_save(self, val):
             if self.serialize_as == 'table':
@@ -179,7 +180,7 @@ class Array(Object):
                 return literal(out.getvalue().decode('utf-8'))
             elif self.serialize_as == 'base64' \
                     or self.serialize_as == 'base64-compat':
-                data = val.astype(self.serialize_dtype).tostring()
+                data = val.astype(self.serialize_dtype).tobytes()
                 return literal(b64encode(data).decode('utf-8'))
             elif self.serialize_as == 'list':
                 if self.dtype == complex:
@@ -200,7 +201,7 @@ class Array(Object):
                 serialize_dtype = self.serialize_dtype or \
                     restricted_dtype_map[val.dtype]
 
-                data = val.astype(serialize_dtype).tostring()
+                data = val.astype(serialize_dtype).tobytes()
 
                 return dict(
                     dtype=serialize_dtype,
