@@ -2,6 +2,26 @@
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
+
+'''
+QuakeML 1.2 input, output, and data model.
+
+This modules provides support to read and write `QuakeML version 1.2
+<https://quake.ethz.ch/quakeml>`_. It defines a hierarchy of Python objects,
+closely following the QuakeML data model.
+
+QuakeML is a flexible, extensible and modular XML representation of
+seismological data which is intended to cover a broad range of fields of
+application in modern seismology. It covers basic seismic event description,
+including moment tensors.
+
+For convenience and ease of use, this documentation contains excerpts from the
+`QuakeML Manual
+<https://quake.ethz.ch/quakeml/docs/REC?action=AttachFile&do=get&target=QuakeML-BED-20130214b.pdf>`_.
+However, this information is not intended to be complete. Please refer to the
+QuakeML Manual for details.
+'''
+
 from __future__ import absolute_import
 import logging
 from pyrocko.guts import StringPattern, StringChoice, String, Float, Int,\
@@ -37,6 +57,14 @@ def one_element_or_none(li):
 
 
 class ResourceIdentifier(StringPattern):
+    '''
+    Identifies resource origin.
+
+    They consist of an authority identifier, a unique resource identifier, and
+    an optional local identifier. The URI schema name smi stands for
+    seismological meta-information, thus indicating a connection to a set of
+    metadata associated with the resource.
+    '''
     pattern = "^(smi|quakeml):[\\w\\d][\\w\\d\\-\\.\\*\\(\\)_~']{2,}/[\\w" +\
         "\\d\\-\\.\\*\\(\\)_~'][\\w\\d\\-\\.\\*\\(\\)\\+\\?_~'=,;#/&]*$"
 
@@ -46,6 +74,9 @@ class WhitespaceOrEmptyStringType(StringPattern):
 
 
 class OriginUncertaintyDescription(StringChoice):
+    '''
+    Preferred uncertainty description.
+    '''
     choices = [
         'horizontal uncertainty',
         'uncertainty ellipse',
@@ -53,10 +84,22 @@ class OriginUncertaintyDescription(StringChoice):
 
 
 class AmplitudeCategory(StringChoice):
+    '''
+    Description of the way the waveform trace is evaluated to get an amplitude
+    value.
+
+    This can be just reading a single value for a given point in time (point),
+    taking a mean value over a time interval (mean), integrating the trace
+    over a time interval (integral), specifying just a time interval
+    (duration), or evaluating a period (period).
+    '''
     choices = ['point', 'mean', 'duration', 'period', 'integral', 'other']
 
 
 class OriginDepthType(StringChoice):
+    '''
+    Type of depth determination.
+    '''
     choices = [
         'from location',
         'from moment tensor inversion',
@@ -69,6 +112,9 @@ class OriginDepthType(StringChoice):
 
 
 class OriginType(StringChoice):
+    '''
+    Describes the origin type.
+    '''
     choices = [
         'hypocenter',
         'centroid',
@@ -79,22 +125,46 @@ class OriginType(StringChoice):
 
 
 class MTInversionType(StringChoice):
+    '''
+    Type of moment tensor inversion.
+
+    Users should avoid to give contradictory information in
+    :py:class:`MTInversionType` and :py:gattr:`MomentTensor.method_id`.
+    '''
     choices = ['general', 'zero trace', 'double couple']
 
 
 class EvaluationMode(StringChoice):
+    '''
+    Mode of an evaluation.
+
+    Used in :py:class:`Pick`, :py:class:`Amplitude`, :py:class:`Magnitude`,
+    :py:class:`Origin`, :py:class:`FocalMechanism`.
+    '''
     choices = ['manual', 'automatic']
 
 
 class EvaluationStatus(StringChoice):
+    '''
+    Status of an evaluation.
+
+    Used in :py:class:`Pick`, :py:class:`Amplitude`, :py:class:`Magnitude`,
+    :py:class:`Origin`, :py:class:`FocalMechanism`.
+    '''
     choices = ['preliminary', 'confirmed', 'reviewed', 'final', 'rejected']
 
 
 class PickOnset(StringChoice):
+    '''
+    Flag that roughly categorizes the sharpness of the onset.
+    '''
     choices = ['emergent', 'impulsive', 'questionable']
 
 
 class EventType(StringChoice):
+    '''
+    Describes the type of an event.
+    '''
     choices = [
         'not existing',
         'not reported',
@@ -145,6 +215,9 @@ class EventType(StringChoice):
 
 
 class DataUsedWaveType(StringChoice):
+    '''
+    Type of waveform data.
+    '''
     choices = [
         'P waves',
         'body waves',
@@ -155,10 +228,20 @@ class DataUsedWaveType(StringChoice):
 
 
 class AmplitudeUnit(StringChoice):
+    '''
+    Provides the most likely measurement units.
+
+    The measurement units for physical quantity are described in the
+    :py:gattr:`Amplitude.generic_amplitude` attribute. Possible values are
+    specified as combination of SI base units.
+    '''
     choices = ['m', 's', 'm/s', 'm/(s*s)', 'm*s', 'dimensionless', 'other']
 
 
 class EventDescriptionType(StringChoice):
+    '''
+    Category of earthquake description.
+    '''
     choices = [
         'felt report',
         'Flinn-Engdahl region',
@@ -170,14 +253,23 @@ class EventDescriptionType(StringChoice):
 
 
 class MomentTensorCategory(StringChoice):
+    '''
+    Category of moment tensor inversion.
+    '''
     choices = ['teleseismic', 'regional']
 
 
 class EventTypeCertainty(StringChoice):
+    '''
+    Denotes how certain the information on event type is.
+    '''
     choices = ['known', 'suspected']
 
 
 class SourceTimeFunctionType(StringChoice):
+    '''
+    Type of source time function.
+    '''
     choices = ['box car', 'triangle', 'trapezoid', 'unknown']
 
 
@@ -250,6 +342,10 @@ class IntegerQuantity(Object):
 
 
 class ConfidenceEllipsoid(Object):
+    '''
+    Representation of the location uncertainty as a confidence ellipsoid with
+    arbitrary orientation in space.
+    '''
     semi_major_axis_length = Float.T()
     semi_minor_axis_length = Float.T()
     semi_intermediate_axis_length = Float.T()
@@ -259,6 +355,12 @@ class ConfidenceEllipsoid(Object):
 
 
 class TimeQuantity(Object):
+    '''
+    Representation of a point in time.
+
+    It's given in ISO 8601 format, with optional symmetric or asymmetric
+    uncertainties given in seconds. The time has to be specified in UTC.
+    '''
     value = Timestamp.T()
     uncertainty = Float.T(optional=True)
     lower_uncertainty = Float.T(optional=True)
@@ -267,16 +369,31 @@ class TimeQuantity(Object):
 
 
 class TimeWindow(Object):
+    '''
+    Representation of a time window for amplitude measurements.
+
+    Which is given by a central point in time, and points in time before and
+    after this central point. Both points before and after may coincide with
+    the central point.
+    '''
     begin = Float.T()
     end = Float.T()
     reference = Timestamp.T()
 
 
 class ResourceReference(ResourceIdentifier):
+    '''
+    This type is used to refer to QuakeML resources as described in Sect. 3.1
+    in the `QuakeML manual <https://quake.ethz.ch/quakeml/docs/REC?action=Att\
+    achFile&do=get&target=QuakeML-BED-20130214b.pdf>`_.
+    '''
     pass
 
 
 class DataUsed(Object):
+    '''
+    Description of the type of data used in a moment-tensor inversion.
+    '''
     wave_type = DataUsedWaveType.T()
     station_count = Int.T(optional=True)
     component_count = Int.T(optional=True)
@@ -285,11 +402,20 @@ class DataUsed(Object):
 
 
 class EventDescription(Object):
+    '''
+    Free-form string with additional event description.
+
+    This can be a well-known name, like 1906 San Francisco Earthquake.
+    A number of categories can be given in :py:gattr:`type`.
+    '''
     text = Unicode.T()
     type = EventDescriptionType.T(optional=True)
 
 
 class SourceTimeFunction(Object):
+    '''
+    Source time function used in moment-tensor inversion.
+    '''
     type = SourceTimeFunctionType.T()
     duration = Float.T()
     rise_time = Float.T(optional=True)
@@ -297,6 +423,14 @@ class SourceTimeFunction(Object):
 
 
 class OriginQuality(Object):
+    '''
+    Description of an origin's quality.
+
+    It contains various attributes commonly used to describe the
+    quality of an origin, e. g., errors, azimuthal coverage, etc.
+    :py:class:`Origin` objects have an optional attribute of the type
+    :py:gattr:`OriginQuality`.
+    '''
     associated_phase_count = Int.T(optional=True)
     used_phase_count = Int.T(optional=True)
     associated_station_count = Int.T(optional=True)
@@ -312,12 +446,27 @@ class OriginQuality(Object):
 
 
 class Axis(Object):
+    '''
+    Representation of an eigenvector of a moment tensor.
+
+    Which is expressed in its principal-axes system and  uses the angles
+    :py:gattr:`azimuth`, :py:gattr:`plunge`, and the eigenvalue
+    :py:gattr:`length`.
+    '''
     azimuth = RealQuantity.T()
     plunge = RealQuantity.T()
     length = RealQuantity.T()
 
 
 class Tensor(Object):
+    '''
+    Representation of the six independent moment-tensor elements in spherical
+    coordinates.
+
+    These are the moment-tensor elements Mrr, Mtt, Mpp, Mrt, Mrp, Mtp in the
+    spherical coordinate system defined by local upward vertical (r),
+    North-South (t), and West-East (p) directions.
+    '''
     mrr = RealQuantity.T(xmltagname='Mrr')
     mtt = RealQuantity.T(xmltagname='Mtt')
     mpp = RealQuantity.T(xmltagname='Mpp')
@@ -327,12 +476,22 @@ class Tensor(Object):
 
 
 class NodalPlane(Object):
+    '''
+    Description of a nodal plane of a focal mechanism.
+    '''
     strike = RealQuantity.T()
     dip = RealQuantity.T()
     rake = RealQuantity.T()
 
 
 class CompositeTime(Object):
+    '''
+    Representation of a time instant.
+
+    If the specification is given with no greater accuracy than days (i.e., no
+    time components are given), the date refers to local time. However, if
+    time components are given, they have to refer to UTC.
+    '''
     year = IntegerQuantity.T(optional=True)
     month = IntegerQuantity.T(optional=True)
     day = IntegerQuantity.T(optional=True)
@@ -342,6 +501,14 @@ class CompositeTime(Object):
 
 
 class OriginUncertainty(Object):
+    '''
+    Description of the location uncertainties of an origin.
+
+    The uncertainty can be described either as a simple circular horizontal
+    uncertainty, an uncertainty ellipse according to IMS1.0, or a confidence
+    ellipsoid. If multiple uncertainty models are given, the preferred variant
+    can be specified in the attribute :py:gattr:`preferred_description`.
+    '''
     horizontal_uncertainty = Float.T(optional=True)
     min_horizontal_uncertainty = Float.T(optional=True)
     max_horizontal_uncertainty = Float.T(optional=True)
@@ -356,6 +523,10 @@ class ResourceReferenceOptional(Union):
 
 
 class CreationInfo(Object):
+    '''
+    Description of creation metadata (author, version, and creation time) of a
+    resource.
+    '''
     agency_id = AgencyID.T(optional=True, xmltagname='agencyID')
     agency_uri = ResourceReference.T(optional=True, xmltagname='agencyURI')
     author = Author.T(optional=True)
@@ -365,24 +536,55 @@ class CreationInfo(Object):
 
 
 class StationMagnitudeContribution(Object):
+    '''
+    Description of the weighting of magnitude values from several
+    :py:class:`StationMagnitude` objects for computing a network magnitude
+    estimation.
+    '''
     station_magnitude_id = ResourceReference.T(xmltagname='stationMagnitudeID')
     residual = Float.T(optional=True)
     weight = Float.T(optional=True)
 
 
 class PrincipalAxes(Object):
+    '''
+    Representation of the principal axes of a moment tensor.
+
+    :py:gattr:`t_axis` and :py:gattr:`p_axis` are required, while
+    :py:gattr:`n_axis` is optional.
+    '''
     t_axis = Axis.T()
     p_axis = Axis.T()
     n_axis = Axis.T(optional=True)
 
 
 class NodalPlanes(Object):
+    '''
+    Representation of the nodal planes of a moment tensor.
+
+    The attribute :py:gattr:`preferred_plane` can be used to define which plane
+    is the preferred one.
+    '''
     preferred_plane = Int.T(optional=True, xmlstyle='attribute')
     nodal_plane1 = NodalPlane.T(optional=True)
     nodal_plane2 = NodalPlane.T(optional=True)
 
 
 class WaveformStreamID(Object):
+    '''
+    Reference to a stream description in an inventory.
+
+    This is mostly equivalent to the combination of networkCode, stationCode,
+    locationCode, and channelCode. However, additional information, e.g.,
+    sampling rate, can be referenced by the resourceURI. It is recommended to
+    use resourceURI as a flexible, abstract, and unique stream ID that allows
+    to describe different processing levels, or resampled/filtered products of
+    the same initial stream, without violating the intrinsic meaning of the
+    legacy identifiers (:py:gattr:`network_code`, :py:gattr:`station_code`,
+    :py:gattr:`channel_code`, and :py:gattr:`location_code`). However, for
+    operation in the context of legacy systems, the classical identifier
+    components are supported.
+    '''
     value = ResourceReferenceOptional.T(xmlstyle='content')
     network_code = AnonymousNetworkCode.T(xmlstyle='attribute')
     station_code = AnonymousStationCode.T(xmlstyle='attribute')
@@ -397,12 +599,20 @@ class WaveformStreamID(Object):
 
 
 class Comment(Object):
+    '''
+    Comment to a resource together with author and creation time information.
+    '''
     id = ResourceReference.T(optional=True, xmlstyle='attribute')
     text = Unicode.T()
     creation_info = CreationInfo.T(optional=True)
 
 
 class MomentTensor(Object):
+    '''
+    Representation of a moment tensor solution for an event.
+
+    It is an optional part of a :py:class:`FocalMechanism` description.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     data_used_list = List.T(DataUsed.T())
@@ -434,13 +644,19 @@ class MomentTensor(Object):
         mrt = self.tensor.mrt.value
         mrp = self.tensor.mrp.value
         mtp = self.tensor.mtp.value
-        mt = moment_tensor.MomentTensor(m_up_south_east=num.matrix([
+        mt = moment_tensor.MomentTensor(m_up_south_east=num.array([
              [mrr, mrt, mrp], [mrt, mtt, mtp], [mrp, mtp, mpp]]))
 
         return mt
 
 
 class Amplitude(Object):
+    '''
+    Quantification of the waveform anomaly.
+
+    Usually it consists of a single amplitude measurement or a measurement of
+    the visible signal duration for duration magnitudes.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     comment_list = List.T(Comment.T())
@@ -463,6 +679,14 @@ class Amplitude(Object):
 
 
 class Magnitude(Object):
+    '''
+    Description of a magnitude value.
+
+    It can, but does not need to be associated with an origin. Association
+    with an origin is expressed with the optional attribute
+    :py:gattr:`origin_id`. It is either a combination of different magnitude
+    estimations, or it represents the reported magnitude for the given event.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     comment_list = List.T(Comment.T())
@@ -480,6 +704,9 @@ class Magnitude(Object):
 
 
 class StationMagnitude(Object):
+    '''
+    Description of a magnitude derived from a single waveform stream.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     comment_list = List.T(Comment.T())
@@ -493,6 +720,19 @@ class StationMagnitude(Object):
 
 
 class Arrival(Object):
+    '''
+    Successful association of a pick with an origin qualifies this pick as an
+    arrival.
+
+    An arrival thus connects a pick with an origin and provides
+    additional attributes that describe this relationship. Usually
+    qualification of a pick as an arrival for a given origin is a hypothesis,
+    which is based on assumptions about the type of arrival (phase) as well as
+    observed and (on the basis of an earth model) computed arrival times, or
+    the residual, respectively. Additional pick attributes like the horizontal
+    slowness and backazimuth of the observed wave—especially if derived from
+    array data—may further constrain the nature of the arrival.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     comment_list = List.T(Comment.T())
@@ -515,6 +755,12 @@ class Arrival(Object):
 
 
 class Pick(Object):
+    '''
+    A pick is the observation of an amplitude anomaly in a seismogram at a
+    specific point in time.
+
+    It is not necessarily related to a seismic event.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     comment_list = List.T(Comment.T())
@@ -539,7 +785,7 @@ class Pick(Object):
 
     def get_pyrocko_phase_marker(self, event=None):
         if not self.phase_hint:
-            logger.warn('Pick %s: phase_hint undefined' % self.public_id)
+            logger.warning('Pick %s: phase_hint undefined' % self.public_id)
             phasename = 'undefined'
         else:
             phasename = self.phase_hint.value
@@ -553,6 +799,14 @@ class Pick(Object):
 
 
 class FocalMechanism(Object):
+    '''
+    Description of the focal mechanism of an event.
+
+    It includes different descriptions like nodal planes, principal axes, and
+    a moment tensor. The moment tensor description is provided by objects of
+    the class :py:class:`MomentTensor` which can be specified as
+    child elements of :py:class:`FocalMechanism`.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     waveform_id_list = List.T(WaveformStreamID.T(xmltagname='waveformID'))
@@ -573,6 +827,13 @@ class FocalMechanism(Object):
 
 
 class Origin(Object):
+    '''
+    Representation of the focal time and geographical location of an earthquake
+    hypocenter, as well as additional meta-information.
+
+    :py:class:`Origin` can have objects of type :py:class:`OriginUncertainty`
+    and :py:class:`Arrival` as child elements.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     composite_time_list = List.T(CompositeTime.T())
@@ -602,7 +863,7 @@ class Origin(Object):
         lat = self.latitude.value
         lon = self.longitude.value
         if not self.depth:
-            logger.warn(
+            logger.warning(
                 'Origin %s: Depth is undefined. Set to depth=0.' %
                 self.public_id)
             depth = 0.
@@ -630,6 +891,23 @@ class Origin(Object):
 
 
 class Event(Object):
+    '''
+    Representation of a seismic event.
+
+    The Event does not necessarily need to be a tectonic earthquake. An event
+    is usually associated with one or more origins, which contain information
+    about focal time and geographical location of the event. Multiple origins
+    can cover automatic and manual locations, a set of location from different
+    agencies, locations generated with different location programs and earth
+    models, etc. Furthermore, an event is usually associated with one or more
+    magnitudes, and with one or more focal mechanism determinations. In
+    standard QuakeML-BED, :py:class:`Origin`, :py:class:`Magnitude`,
+    :py:class:`StationMagnitude`, and :py:class:`FocalMechanism` are child
+    elements of Event. In BED-RT all these elements are on the same hierarchy
+    level as child elements of :py:class:`EventParameters`. The association of
+    origins, magnitudes, and focal mechanisms to a particular event is
+    expressed using references inside :py:class:`Event`.
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     description_list = List.T(EventDescription.T())
@@ -692,7 +970,7 @@ class Event(Object):
         if not origin and self.origin_list:
             origin = self.origin_list[0]
             if len(self.origin_list) > 1:
-                logger.warn(
+                logger.warning(
                     'Event %s: No preferred origin set, '
                     'more than one available, using first' % self.public_id)
 
@@ -706,7 +984,7 @@ class Event(Object):
         if not foc_mech and self.focal_mechanism_list:
             foc_mech = self.focal_mechanism_list[0]
             if len(self.focal_mechanism_list) > 1:
-                logger.warn(
+                logger.warning(
                     'Event %s: No preferred focal mechanism set, '
                     'more than one available, using first' % ev.name)
 
@@ -715,7 +993,7 @@ class Event(Object):
                 foc_mech.moment_tensor_list[0].pyrocko_moment_tensor()
 
             if len(foc_mech.moment_tensor_list) > 1:
-                logger.warn(
+                logger.warning(
                     'more than one moment tensor available, using first')
 
         mag = None
@@ -725,7 +1003,7 @@ class Event(Object):
         elif self.magnitude_list:
             mag = self.magnitude_list[0]
             if len(self.magnitude_list) > 1:
-                logger.warn(
+                logger.warning(
                     'Event %s: No preferred magnitude set, '
                     'more than one available, using first' % ev.name)
 
@@ -767,6 +1045,16 @@ class Event(Object):
 
 
 class EventParameters(Object):
+    '''
+    In the bulletin-type (non real-time) model, this class serves as a
+    container for Event objects.
+
+    In the real-time version, it can hold objects of type :py:class:`Event`,
+    :py:class:`Origin`, :py:class:`Magnitude`, :py:class:`StationMagnitude`,
+    :py:class:`FocalMechanism`, Reading, :py:class:`Amplitude` and
+    :py:class:`Pick` (real-time mode is not covered by this module at the
+    moment).
+    '''
     public_id = ResourceReference.T(
         xmlstyle='attribute', xmltagname='publicID')
     comment_list = List.T(Comment.T())
@@ -776,6 +1064,9 @@ class EventParameters(Object):
 
 
 class QuakeML(Object):
+    '''
+    QuakeML data container.
+    '''
     xmltagname = 'quakeml'
     xmlns = 'http://quakeml.org/xmlns/quakeml/1.2'
     guessable_xmlns = [xmlns, guts_xmlns]
@@ -787,7 +1078,10 @@ class QuakeML(Object):
 
     def get_pyrocko_events(self):
         '''
-        Extract a list of :py:class:`pyrocko.model.Event` instances
+        Get event information in Pyrocko's basic event format.
+
+        :rtype:
+            List of :py:class:`pyrocko.model.event.Event` objects.
         '''
         events = []
         for e in self.event_parameters.event_list:
@@ -796,6 +1090,12 @@ class QuakeML(Object):
         return events
 
     def get_pyrocko_phase_markers(self):
+        '''
+        Get pick information in Pyrocko's basic marker format.
+
+        :rtype:
+            List of :py:class:`pyrocko.gui.marker.PhaseMarker` objects.
+        '''
         markers = []
         for e in self.event_parameters.event_list:
             markers.extend(e.get_pyrocko_phase_markers())
@@ -803,11 +1103,40 @@ class QuakeML(Object):
         return markers
 
     @classmethod
-    def load_xml(cls, *args, **kwargs):
-        kwargs['ns_hints'] = [
-            'http://quakeml.org/xmlns/quakeml/1.2',
-            'http://quakeml.org/xmlns/bed/1.2']
+    def load_xml(cls, stream=None, filename=None, string=None):
+        '''
+        Load QuakeML data from stream, file or string.
 
-        kwargs['ns_ignore'] = True
+        :param stream:
+            Stream open for reading in binary mode.
+        :type stream:
+            file-like object, optional
 
-        return super(QuakeML, cls).load_xml(*args, **kwargs)
+        :param filename:
+            Path to file to be opened for reading.
+        :type filename:
+            str, optional
+
+        :param string:
+            String with QuakeML data to be deserialized.
+        :type string:
+            str, optional
+
+        The arguments ``stream``, ``filename``, and ``string`` are mutually
+        exclusive.
+
+        :returns:
+            Parsed QuakeML data structure.
+        :rtype:
+            :py:class:`QuakeML` object
+
+        '''
+
+        return super(QuakeML, cls).load_xml(
+            stream=stream,
+            filename=filename,
+            string=string,
+            ns_hints=[
+                'http://quakeml.org/xmlns/quakeml/1.2',
+                'http://quakeml.org/xmlns/bed/1.2'],
+            ns_ignore=True)
