@@ -146,7 +146,7 @@ class GNSSStation(Location):
     def get_component_mask(self):
         return num.array(
             [False if self.__getattribute__(name) is None else True
-             for name in ('north', 'east', 'up')], dtype=num.bool)
+             for name in ('north', 'east', 'up')], dtype=bool)
 
     @property
     def components(self):
@@ -209,8 +209,8 @@ class GNSSCampaign(Object):
             self._cor_mat = None
             self._cov_mat = None
         except ValueError:
-            logger.warn('Station {} does not exist in campaign, '
-                        'do nothing.'.format(station_code))
+            logger.warning('Station {} does not exist in campaign, '
+                           'do nothing.'.format(station_code))
 
     def get_station(self, station_code):
         for sta in self.stations:
