@@ -155,6 +155,8 @@ class Map(Object):
     show_center_mark = Bool.T(default=False)
     show_rivers = Bool.T(default=True)
     show_plates = Bool.T(default=False)
+    show_plate_velocities = Bool.T(default=False)
+    show_plate_names = Bool.T(default=False)
     show_boundaries = Bool.T(default=False)
     illuminate_factor_land = Float.T(default=0.5)
     illuminate_factor_ocean = Float.T(default=0.25)
@@ -176,6 +178,7 @@ class Map(Object):
     custom_cities = List.T(City.T())
     gmt_config = Dict.T(String.T(), String.T())
     comment = String.T(optional=True)
+    approx_ticks = Int.T(default=4)
 
     def __init__(self, gmtversion='newest', **kwargs):
         Object.__init__(self, **kwargs)
@@ -197,7 +200,7 @@ class Map(Object):
         self._gmtversion = gmtversion
 
     def save(self, outpath, resolution=75., oversample=2., size=None,
-             width=None, height=None, psconvert=False):
+             width=None, height=None, psconvert=False, crop_eps_mode=False):
 
         '''
         Save the image.
@@ -214,7 +217,8 @@ class Map(Object):
         controlled either by ``resolution`` in DPI or by specifying ``width``
         or ``height`` or ``size``, where the latter fits the image into a
         square with given side length. To save transparency use
-        ``psconvert=True``.
+        ``psconvert=True``. To crop the output image with a rectangle to the
+        nearest non-white element set ``crop_eps_mode=True``.
         '''
 
         gmt = self.gmt
@@ -224,6 +228,7 @@ class Map(Object):
             self._draw_topo_scale()
 
         gmt.save(outpath, resolution=resolution, oversample=oversample,
+                 crop_eps_mode=crop_eps_mode,
                  size=size, width=width, height=height, psconvert=psconvert)
 
     @property
@@ -306,8 +311,8 @@ class Map(Object):
 
         x, y, z = ((west, east), (south, north), (-6000., 4500.))
 
-        xax = gmtpy.Ax(mode='min-max', approx_ticks=4.)
-        yax = gmtpy.Ax(mode='min-max', approx_ticks=4.)
+        xax = gmtpy.Ax(mode='min-max', approx_ticks=self.approx_ticks)
+        yax = gmtpy.Ax(mode='min-max', approx_ticks=self.approx_ticks)
         zax = gmtpy.Ax(mode='min-max', inc=1000., label='Height',
                        scaled_unit='km', scaled_unit_factor=0.001)
 
@@ -918,7 +923,7 @@ class Map(Object):
 
                 rects = [xs-0.5*dx, ys-0.5*dy, xs+0.5*dx, ys+0.5*dy]
 
-                locs_ok = num.ones(xs.size, dtype=num.bool)
+                locs_ok = num.ones(xs.size, dtype=bool)
 
                 for iloc in range(xs.size):
                     rcandi = [xxx[iloc] for xxx in rects]
@@ -1109,7 +1114,7 @@ class Map(Object):
 
         if vertical:
             rows = [[lons[ista], lats[ista],
-                    0., s.up.shift,
+                    0., -s.up.shift,
                     (s.east.sigma + s.north.sigma) if s.east.sigma else 0.,
                     s.up.sigma, 0.,
                     s.code if labels else None]
@@ -1118,7 +1123,7 @@ class Map(Object):
 
         else:
             rows = [[lons[ista], lats[ista],
-                     s.east.shift, s.north.shift,
+                     -s.east.shift, -s.north.shift,
                      s.east.sigma, s.north.sigma, s.correlation_ne,
                      s.code if labels else None]
                     for ista, s in enumerate(stations)
@@ -1127,7 +1132,7 @@ class Map(Object):
         default_psxy_style = {
             'h': 0,
             'W': '2p,black',
-            'A': '+p2p,black+e+a40',
+            'A': '+p2p,black+b+a40',
             'G': 'black',
             'L': True,
             'S': 'e%dc/0.95/%d' % (scale, fontsize),
@@ -1194,7 +1199,7 @@ class Map(Object):
 
             boundaries = bird.get_boundaries()
 
-            size = 2
+            size = 1.
 
             psxy_kwargs = []
 
@@ -1202,11 +1207,16 @@ class Map(Object):
                 if num.any(points_in_region(boundary.points, self._wesn)):
                     for typ, part in boundary.split_types(
                             [['SUB'],
-                             ['OSR', 'OTF', 'OCB', 'CTF', 'CCB', 'CRB']]):
+                             ['OSR', 'CRB'],
+                             ['OTF', 'CTF', 'OCB', 'CCB']]):
 
                         lats, lons = part.T
 
                         kwargs = {}
+
+                        kwargs['in_columns'] = (lons, lats)
+                        kwargs['W'] = '%gp,%s' % (size, color_plates)
+
                         if typ[0] == 'SUB':
                             if boundary.kind == '\\':
                                 kwargs['S'] = 'f%g/%gp+t+r' % (
@@ -1217,18 +1227,26 @@ class Map(Object):
 
                             kwargs['G'] = color_plates
 
-                        kwargs['in_columns'] = (lons, lats)
-                        kwargs['W'] = '%gp,%s' % (size, color_plates),
+                        elif typ[0] in ['OSR', 'CRB']:
+                            kwargs_bg = {}
+                            kwargs_bg['in_columns'] = (lons, lats)
+                            kwargs_bg['W'] = '%gp,%s' % (
+                                size * 3, color_plates)
+                            psxy_kwargs.append(kwargs_bg)
+
+                            kwargs['W'] = '%gp,%s' % (size * 2, 'white')
 
                         psxy_kwargs.append(kwargs)
 
                         if boundary.kind == '\\':
-                            if boundary.name2 in candi_fixed:
-                                candi_fixed[boundary.name2] += neast*nnorth
+                            if boundary.plate_name2 in candi_fixed:
+                                candi_fixed[boundary.plate_name2] += \
+                                    neast*nnorth
 
                         elif boundary.kind == '/':
-                            if boundary.name1 in candi_fixed:
-                                candi_fixed[boundary.name1] += neast*nnorth
+                            if boundary.plate_name1 in candi_fixed:
+                                candi_fixed[boundary.plate_name1] += \
+                                    neast*nnorth
 
             candi_fixed = [name for name in sorted(
                 list(candi_fixed.keys()), key=lambda name: -candi_fixed[name])]
@@ -1248,36 +1266,38 @@ class Map(Object):
 
                 fixed_plate_name = name
 
-                self.gmt.psvelo(
-                    in_columns=(
-                        lons, lats, veast, vnorth, veast_err, vnorth_err,
-                        corr),
-                    W='0.25p,%s' % color_velocities,
-                    A='9p+e+g%s' % color_velocities,
-                    S='e0.2p/0.95/10',
-                    *self.jxyr)
+                if self.show_plate_velocities:
+                    self.gmt.psvelo(
+                        in_columns=(
+                            lons, lats, veast, vnorth, veast_err, vnorth_err,
+                            corr),
+                        W='0.25p,%s' % color_velocities,
+                        A='9p+e+g%s' % color_velocities,
+                        S='e0.2p/0.95/10',
+                        *self.jxyr)
 
-                for _ in range(len(lons) // 50 + 1):
-                    ii = random.randint(0, len(lons)-1)
-                    v = math.sqrt(vnorth[ii]**2 + veast[ii]**2)
-                    self.add_label(
-                        lats[ii], lons[ii], '%.0f' % v,
-                        font_size=0.7*self.gmt.label_font_size(),
-                        style=dict(
-                            G=color_velocities_lab))
+                    for _ in range(len(lons) // 50 + 1):
+                        ii = random.randint(0, len(lons)-1)
+                        v = math.sqrt(vnorth[ii]**2 + veast[ii]**2)
+                        self.add_label(
+                            lats[ii], lons[ii], '%.0f' % v,
+                            font_size=0.7*self.gmt.label_font_size(),
+                            style=dict(
+                                G=color_velocities_lab))
 
-                break
+                    break
 
-            for (lat_candis, lon_candis, plate, color) in label_data:
-                full_name = bird.full_name(plate.name)
-                if plate.name == fixed_plate_name:
-                    full_name = '@_' + full_name + '@_'
+            if self.show_plate_names:
+                for (lat_candis, lon_candis, plate, color) in label_data:
+                    full_name = bird.full_name(plate.name)
+                    if plate.name == fixed_plate_name:
+                        full_name = '@_' + full_name + '@_'
 
-                self.add_area_label(
-                    lat_candis, lon_candis,
-                    full_name,
-                    color=color,
-                    font='3')
+                    self.add_area_label(
+                        lat_candis, lon_candis,
+                        full_name,
+                        color=color,
+                        font='3')
 
             for kwargs in psxy_kwargs:
                 self.gmt.psxy(*self.jxyr, **kwargs)
