@@ -15,6 +15,7 @@ from functools import reduce
 from pyrocko.guts import StringChoice, Float, List, Bool
 from pyrocko.gui.marker import PhaseMarker, EventMarker
 from pyrocko import gf, model, util, trace, io
+from pyrocko.response import DifferentiationResponse
 from pyrocko.io.io_common import FileSaveError
 from pyrocko import pile
 
@@ -75,9 +76,10 @@ class WhiteNoiseGenerator(WaveformNoiseGenerator):
 
 class WaveformGenerator(TargetGenerator):
 
-    station_generator = StationGenerator.T(
-        default=RandomStationGenerator.D(),
-        help='The StationGenerator for creating the stations.')
+    station_generators = List.T(
+        StationGenerator.T(),
+        default=[RandomStationGenerator.D()],
+        help='List of StationGenerators.')
 
     noise_generator = WaveformNoiseGenerator.T(
         default=WhiteNoiseGenerator.D(),
@@ -93,10 +95,10 @@ class WaveformGenerator(TargetGenerator):
 
     vmin_cut = Float.T(
         default=2000.,
-        help='Minimum velocity to seismic velicty to consider in the model.')
+        help='Minimum velocity to seismic velocity to consider in the model.')
     vmax_cut = Float.T(
         default=8000.,
-        help='Maximum velocity to seismic velicty to consider in the model.')
+        help='Maximum velocity to seismic velocity to consider in the model.')
 
     fmin = Float.T(
         default=0.01,
@@ -155,7 +157,16 @@ class WaveformGenerator(TargetGenerator):
         return self._piles[apath]
 
     def get_stations(self):
-        return self.station_generator.get_stations()
+        stations = []
+        for station_generator in self.station_generators:
+            stations.extend(station_generator.get_stations())
+        return stations
+
+    def get_distance_range(self, sources):
+        distances = num.array(
+            [sg.get_distance_range(sources)
+             for sg in self.station_generators])
+        return (distances[:, 0].min(), distances[:, 1].max())
 
     def get_targets(self):
         if self._targets:
@@ -203,7 +214,7 @@ class WaveformGenerator(TargetGenerator):
         return self._targets
 
     def get_time_range(self, sources):
-        dmin, dmax = self.station_generator.get_distance_range(sources)
+        dmin, dmax = self.get_distance_range(sources)
 
         times = num.array([source.time for source in sources],
                           dtype=util.get_time_dtype())
@@ -228,7 +239,7 @@ class WaveformGenerator(TargetGenerator):
         return deltats
 
     def get_useful_time_increment(self, engine, sources):
-        _, dmax = self.station_generator.get_distance_range(sources)
+        _, dmax = self.get_distance_range(sources)
         tinc = dmax / self.vmin_cut + 2.0 / self.fmin
 
         deltats = set(self.get_codes_to_deltat(engine, sources).values())
@@ -237,7 +248,7 @@ class WaveformGenerator(TargetGenerator):
         return tinc
 
     def get_relevant_sources(self, sources, tmin, tmax):
-        dmin, dmax = self.station_generator.get_distance_range(sources)
+        dmin, dmax = self.get_distance_range(sources)
         trange = tmax - tmin
         tmax_pad = trange + tmax + dmin / self.vmax_cut
         tmin_pad = tmin - (dmax / self.vmin_cut + trange)
@@ -351,9 +362,9 @@ class WaveformGenerator(TargetGenerator):
         if self.seismogram_quantity == 'displacement':
             return None
         elif self.seismogram_quantity == 'velocity':
-            return trace.DifferentiationResponse(1)
+            return DifferentiationResponse(1)
         elif self.seismogram_quantity == 'acceleration':
-            return trace.DifferentiationResponse(2)
+            return DifferentiationResponse(2)
         elif self.seismogram_quantity == 'counts':
             raise NotImplementedError()
 
@@ -445,13 +456,16 @@ class WaveformGenerator(TargetGenerator):
         path_responses = op.join(path, 'meta')
         util.ensuredir(path_responses)
 
-        fn_stationxml = op.join(path_responses, 'stations.xml')
-        if op.exists(fn_stationxml):
-            return
+        fn_stationxml = op.join(path_responses, 'waveform_response.xml')
+        i = 0
+        while op.exists(fn_stationxml):
+            fn_stationxml = op.join(
+                path_responses, 'waveform_response-%s.xml' % i)
+            i += 1
 
         logger.debug('Writing waveform meta information to StationXML...')
 
-        stations = self.station_generator.get_stations()
+        stations = self.get_stations()
         sxml = stationxml.FDSNStationXML.from_pyrocko_stations(stations)
 
         sunit = {
