@@ -1,4 +1,5 @@
 # http://pyrocko.org - GPLv3
+
 #
 # The Pyrocko Developers, 21st Century
 # ---|P------/S----------~Lg----------
@@ -83,6 +84,7 @@ from scipy import signal
 import pyrocko
 from pyrocko import dummy_progressbar
 
+
 try:
     from urllib.parse import urlencode, quote, unquote  # noqa
     from urllib.request import (
@@ -94,6 +96,13 @@ except ImportError:
     from urllib2 import (Request, build_opener, HTTPDigestAuthHandler,   # noqa
                          HTTPError, URLError, urlopen as _urlopen)  # noqa
 
+try:
+    import certifi
+    import ssl
+    g_ssl_context = ssl.create_default_context(cafile=certifi.where())
+except ImportError:
+    g_ssl_context = None
+
 
 class URLErrorSSL(URLError):
 
@@ -120,12 +129,9 @@ def urlopen_ssl_check(*args, **kwargs):
 
 
 def urlopen(*args, **kwargs):
-    if 'cafile' not in kwargs:
-        try:
-            import certifi
-            kwargs['cafile'] = certifi.where()
-        except ImportError:
-            pass
+
+    if 'context' not in kwargs and g_ssl_context is not None:
+        kwargs['context'] = g_ssl_context
 
     return _urlopen(*args, **kwargs)
 
@@ -201,7 +207,7 @@ def setup_logging(programname='pyrocko', levelname='warning'):
 
     logging.basicConfig(
         level=levels[levelname],
-        format=programname+':%(name)-20s - %(levelname)-8s - %(message)s')
+        format=programname+':%(name)-25s - %(levelname)-8s - %(message)s')
 
 
 def subprocess_setup_logging_args():
@@ -382,7 +388,7 @@ def _download(url, fpath, username=None, password=None,
                 download_file(url, fpath)
 
     except req_HTTPError as e:
-        logging.warn("http error: %s" % e)
+        logging.warning("http error: %s" % e)
         raise DownloadError('could not download file(s) from: %s' % url)
 
     finally:
@@ -426,8 +432,10 @@ class dummy_hpfloat(object):
 
 if hasattr(num, 'float128'):
     hpfloat = num.float128
+
 elif hasattr(num, 'float96'):
     hpfloat = num.float96
+
 else:
     hpfloat = dummy_hpfloat
 
@@ -585,7 +593,7 @@ def check_time_class(t, error='raise'):
         if error == 'raise':
             raise TimestampTypeError(message)
         elif error == 'warn':
-            logger.warn(message)
+            logger.warning(message)
         else:
             assert False
 
@@ -664,6 +672,21 @@ def wrap(text, line_length=80):
     return outlines
 
 
+def ewrap(lines, width=80, indent=''):
+    lines = list(lines)
+    if not lines:
+        return ''
+    fwidth = max(len(s) for s in lines)
+    nx = max(1, (80-len(indent)) // (fwidth+1))
+    i = 0
+    rows = []
+    while i < len(lines):
+        rows.append(indent + ' '.join(x.ljust(fwidth) for x in lines[i:i+nx]))
+        i += nx
+
+    return '\n'.join(rows)
+
+
 class BetterHelpFormatter(optparse.IndentedHelpFormatter):
 
     def __init__(self, *args, **kwargs):
@@ -1039,6 +1062,7 @@ class GlobalVars(object):
     decitab_nmax = 0
     decitab = {}
     decimate_fir_coeffs = {}
+    decimate_fir_remez_coeffs = {}
     decimate_iir_coeffs = {}
     re_frac = None
 
@@ -1050,17 +1074,28 @@ def decimate_coeffs(q, n=None, ftype='iir'):
     if n is None:
         if ftype == 'fir':
             n = 30
+        elif ftype == 'fir-remez':
+            n = 40*q
         else:
             n = 8
 
     if ftype == 'fir':
         coeffs = GlobalVars.decimate_fir_coeffs
         if (n, 1./q) not in coeffs:
-            coeffs[n, 1./q] = signal.firwin(n+1, 1./q, window='hamming')
+            coeffs[n, 1./q] = signal.firwin(n+1, .75/q, window='hamming')
 
         b = coeffs[n, 1./q]
         return b, [1.], n
 
+    elif ftype == 'fir-remez':
+        coeffs = GlobalVars.decimate_fir_remez_coeffs
+        if (n, 1./q) not in coeffs:
+            coeffs[n, 1./q] = signal.remez(
+                n+1, (0., .75/q, 1./q, 1.),
+                (1., 0.), Hz=2, weight=(1, 50))
+        b = coeffs[n, 1./q]
+        return b, [1.], n
+
     else:
         coeffs = GlobalVars.decimate_iir_coeffs
         if (n, 0.05, 0.8/q) not in coeffs:
@@ -1077,13 +1112,13 @@ def decimate(x, q, n=None, ftype='iir', zi=None, ioff=0):
     By default, an order 8 Chebyshev type I filter is used or a 30 point FIR
     filter with hamming window if ftype is 'fir'.
 
-    :param x: the signal to be downsampled (1D NumPy array)
+    :param x: the signal to be downsampled (1D :class:`numpy.ndarray`)
     :param q: the downsampling factor
     :param n: order of the filter (1 less than the length of the filter for a
-         'fir' filter)
-    :param ftype: type of the filter; can be 'iir' or 'fir'
+         `fir` filter)
+    :param ftype: type of the filter; can be `iir`, `fir` or `fir-remez`
 
-    :returns: the downsampled signal (1D NumPy array)
+    :returns: the downsampled signal (1D :class:`numpy.ndarray`)
 
     '''
 
@@ -1376,6 +1411,14 @@ def iter_years(tmin, tmax):
         t = tend
 
 
+def today():
+    return day_start(time.time())
+
+
+def tomorrow():
+    return day_start(time.time() + 24*60*60)
+
+
 def decitab(n):
     '''
     Get integer decimation sequence for given downampling factor.
@@ -1542,6 +1585,20 @@ def str_to_time(s, format='%Y-%m-%d %H:%M:%S.OPTFRAC'):
 stt = str_to_time
 
 
+def str_to_time_fillup(s):
+    '''
+    Default :py:func:`str_to_time` with filling in of missing values.
+
+    Allows e.g. `'2010-01-01 00:00:00'` as `'2010-01-01 00:00'`,
+    `'2010-01-01 00'`, ..., or `'2010'`.
+    '''
+
+    if len(s) in (4, 7, 10, 13, 16):
+        s += '0000-01-01 00:00:00'[len(s):]
+
+    return str_to_time(s)
+
+
 def time_to_str(t, format='%Y-%m-%d %H:%M:%S.3FRAC'):
     '''
     Get string representation for floating point system time.
@@ -1617,10 +1674,10 @@ def gmtime_x(timestamp):
 
 
 def plural_s(n):
-    if n == 1:
-        return ''
-    else:
-        return 's'
+    if not isinstance(n, int):
+        n = len(n)
+
+    return 's' if n != 1 else ''
 
 
 def ensuredirs(dst):
@@ -1711,81 +1768,123 @@ class Anon(object):
             self.__dict__[k] = dict[k]
 
 
-def select_files(paths, selector=None, regex=None, show_progress=True):
+def iter_select_files(
+        paths,
+        include=None,
+        exclude=None,
+        selector=None,
+        show_progress=True,
+        pass_through=None):
+
+    '''
+    Recursively select files (generator variant).
+
+    See :py:func:`select_files`.
+    '''
+
+    if show_progress:
+        progress_beg('selecting files...')
+
+    ngood = 0
+    check_include = None
+    if include is not None:
+        rinclude = re.compile(include)
+
+        def check_include(path):
+            m = rinclude.search(path)
+            if not m:
+                return False
+
+            if selector is None:
+                return True
+
+            infos = Anon(**m.groupdict())
+            return selector(infos)
+
+    check_exclude = None
+    if exclude is not None:
+        rexclude = re.compile(exclude)
+
+        def check_exclude(path):
+            return not bool(rexclude.search(path))
+
+    if check_include and check_exclude:
+
+        def check(path):
+            return check_include(path) and check_exclude(path)
+
+    elif check_include:
+        check = check_include
+
+    elif check_exclude:
+        check = check_exclude
+
+    else:
+        check = None
+
+    if isinstance(paths, str):
+        paths = [paths]
+
+    for path in paths:
+        if pass_through and pass_through(path):
+            if check is None or check(path):
+                yield path
+
+        elif os.path.isdir(path):
+            for (dirpath, dirnames, filenames) in os.walk(path):
+                dirnames.sort()
+                filenames.sort()
+                for filename in filenames:
+                    path = op.join(dirpath, filename)
+                    if check is None or check(path):
+                        yield os.path.abspath(path)
+                        ngood += 1
+        else:
+            if check is None or check(path):
+                yield os.path.abspath(path)
+                ngood += 1
+
+    if show_progress:
+        progress_end('%i file%s selected.' % (ngood, plural_s(ngood)))
+
+
+def select_files(
+        paths, include=None, exclude=None, selector=None, show_progress=True):
+
     '''
     Recursively select files.
 
     :param paths: entry path names
+    :param include: pattern for conditional inclusion
+    :param exclude: pattern for conditional exclusion
     :param selector: callback for conditional inclusion
-    :param regex: pattern for conditional inclusion
     :param show_progress: if True, indicate start and stop of processing
     :returns: list of path names
 
     Recursively finds all files under given entry points ``paths``. If
-    parameter ``regex`` is a regular expression, only files with matching path
-    names are included. If additionally parameter ``selector`` is given a
+    parameter ``include`` is a regular expression, only files with matching
+    path names are included. If additionally parameter ``selector`` is given a
     callback function, only files for which the callback returns ``True`` are
     included. The callback should take a single argument. The callback is
     called with a single argument, an object, having as attributes, any named
-    groups given in ``regex``.
+    groups given in ``include``.
 
     Examples
 
     To find all files ending in ``'.mseed'`` or ``'.msd'``::
 
         select_files(paths,
-            regex=r'\\.(mseed|msd)$')
+            include=r'\\.(mseed|msd)$')
 
     To find all files ending with ``'$Year.$DayOfYear'``, having set 2009 for
     the year::
 
         select_files(paths,
-            regex=r'(?P<year>\\d\\d\\d\\d)\\.(?P<doy>\\d\\d\\d)$',
+            include=r'(?P<year>\\d\\d\\d\\d)\\.(?P<doy>\\d\\d\\d)$',
             selector=(lambda x: int(x.year) == 2009))
     '''
-
-    if show_progress:
-        progress_beg('selecting files...')
-        if logger.isEnabledFor(logging.DEBUG):
-            sys.stderr.write('\n')
-
-    good = []
-    if regex:
-        rselector = re.compile(regex)
-
-    def addfile(path):
-        if regex:
-            logger.debug("looking at filename: '%s'" % path)
-            m = rselector.search(path)
-            if m:
-                infos = Anon(**m.groupdict())
-                logger.debug("   regex '%s' matches." % regex)
-                for k, v in m.groupdict().items():
-                    logger.debug(
-                        "      attribute '%s' has value '%s'" % (k, v))
-                if selector is None or selector(infos):
-                    good.append(os.path.abspath(path))
-
-            else:
-                logger.debug("   regex '%s' does not match." % regex)
-        else:
-            good.append(os.path.abspath(path))
-
-    if isinstance(paths, str):
-        paths = [paths]
-
-    for path in paths:
-        if os.path.isdir(path):
-            for (dirpath, dirnames, filenames) in os.walk(path):
-                for filename in filenames:
-                    addfile(op.join(dirpath, filename))
-        else:
-            addfile(path)
-
-    if show_progress:
-        progress_end('%i file%s selected.' % (len(good), plural_s(len(good))))
-
-    return good
+    return list(iter_select_files(
+        paths, include, exclude, selector, show_progress))
 
 
 def base36encode(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
@@ -1988,7 +2087,7 @@ def create_lockfile(fn, timeout=None, timewarn=10.):
                         'access to: %s' % (timeout, fn))
 
                 if timewarn is not None and tnow - t0 > timewarn:
-                    logger.warn(
+                    logger.warning(
                         'Waiting since %gs to get exclusive access to: %s' % (
                             timewarn, fn))
 
@@ -2451,8 +2550,7 @@ def make_iload_family(iload_fh, doc_fmt='FMT', doc_yielded_objects='FMT'):
 
     def iload_glob(pattern, **kwargs):
 
-        fns = glob.glob(pattern)
-        for fn in fns:
+        for fn in glob.iglob(pattern):
             for cr in iload_filename(fn, **kwargs):
                 yield cr
 
@@ -2555,6 +2653,22 @@ def consistency_merge(list_of_tuples,
         return tuple([merge(x) for x in list(zip(*list_of_tuples))[1:]])
 
 
+def short_to_list(nmax, it):
+    import itertools
+
+    if isinstance(it, list):
+        return it
+
+    li = []
+    for i in range(nmax+1):
+        try:
+            li.append(next(it))
+        except StopIteration:
+            return li
+
+    return itertools.chain(li, it)
+
+
 def parse_md(f):
     try:
         with open(op.join(
@@ -2583,9 +2697,40 @@ def mpl_show(plt):
 
 g_re_qsplit = re.compile(
     r'"([^"\\]*(?:\\.[^"\\]*)*)"|\'([^\'\\]*(?:\\.[^\'\\]*)*)\'|(\S+)')
+g_re_qsplit_sep = {}
+
+
+def get_re_qsplit(sep):
+    if sep is None:
+        return g_re_qsplit
+    else:
+        if sep not in g_re_qsplit_sep:
+            assert len(sep) == 1
+            assert sep not in '\'"'
+            esep = re.escape(sep)
+            g_re_qsplit_sep[sep] = re.compile(
+                r'"([^"\\]*(?:\\.[^"\\]*)*)"|\'([^\'\\]*(?:\\.[^\'\\]*)*)\'|'
+                + r'([^' + esep + r']+|(?<=' + esep + r')(?=' + esep + r')|^(?=' + esep + r')|(?<=' + esep + r')$)')  # noqa
+        return g_re_qsplit_sep[sep]
 
 
 g_re_trivial = re.compile(r'\A[^\'"\s]+\Z')
+g_re_trivial_sep = {}
+
+
+def get_re_trivial(sep):
+    if sep is None:
+        return g_re_trivial
+    else:
+        if sep not in g_re_qsplit_sep:
+            assert len(sep) == 1
+            assert sep not in '\'"'
+            esep = re.escape(sep)
+            g_re_trivial_sep[sep] = re.compile(r'\A[^\'"' + esep + r']+\Z')
+
+        return g_re_trivial_sep[sep]
+
+
 g_re_escape_s = re.compile(r'([\\\'])')
 g_re_unescape_s = re.compile(r'\\([\\\'])')
 g_re_escape_d = re.compile(r'([\\"])')
@@ -2629,28 +2774,37 @@ def unescape_d(s):
     return g_re_unescape_d.sub(r'\1', s)
 
 
-def qjoin_s(it):
+def qjoin_s(it, sep=None):
     '''
     Join sequence of strings into a line, single-quoting non-trivial strings.
 
     Example:  ``["55", "Sparrow's Island"]`` => ``"55 'Sparrow\\\\'s Island'"``
     '''
-    return ' '.join(
-        w if g_re_trivial.search(w) else "'%s'" % escape_s(w) for w in it)
+    re_trivial = get_re_trivial(sep)
+
+    if sep is None:
+        sep = ' '
+
+    return sep.join(
+        w if re_trivial.search(w) else "'%s'" % escape_s(w) for w in it)
 
 
-def qjoin_d(it):
+def qjoin_d(it, sep=None):
     '''
     Join sequence of strings into a line, double-quoting non-trivial strings.
 
     Example:  ``['55', 'Pete "The Robot" Smith']`` =>
     ``'55' "Pete \\\\"The Robot\\\\" Smith"'``
     '''
-    return ' '.join(
-        w if g_re_trivial.search(w) else '"%s"' % escape_d(w) for w in it)
+    re_trivial = get_re_trivial(sep)
+    if sep is None:
+        sep = ' '
+
+    return sep.join(
+        w if re_trivial.search(w) else '"%s"' % escape_d(w) for w in it)
 
 
-def qsplit(s):
+def qsplit(s, sep=None):
     '''
     Split line into list of strings, allowing for quoted strings.
 
@@ -2659,6 +2813,45 @@ def qsplit(s):
     ``'55' "Pete \\\\"The Robot\\\\" Smith"'`` =>
     ``['55', 'Pete "The Robot" Smith']``
     '''
+    re_qsplit = get_re_qsplit(sep)
     return [
         (unescape_d(x[0]) or unescape_s(x[1]) or x[2])
-        for x in g_re_qsplit.findall(s)]
+        for x in re_qsplit.findall(s)]
+
+
+g_have_warned_threadpoolctl = False
+
+
+class threadpool_limits_dummy(object):
+
+    def __init__(self, *args, **kwargs):
+        pass
+
+    def __enter__(self):
+        global g_have_warned_threadpoolctl
+
+        if not g_have_warned_threadpoolctl:
+            logger.warning(
+                'Cannot control number of BLAS threads because '
+                '`threadpoolctl` module is not available. You may want to '
+                'install `threadpoolctl`.')
+
+            g_have_warned_threadpoolctl = True
+
+        return self
+
+    def __exit__(self, type, value, traceback):
+        pass
+
+
+def get_threadpool_limits():
+    '''
+    Try to import threadpoolctl.threadpool_limits, provide dummy if not avail.
+    '''
+
+    try:
+        from threadpoolctl import threadpool_limits
+        return threadpool_limits
+
+    except ImportError:
+        return threadpool_limits_dummy
